@@ -180,6 +180,11 @@ class Counter(object):
         audit_log.info('increment counter entity=%s attr_key=%s value=%s', self.entity.name, self.attr_key, self.value)
         return self.value
 
+    def delete(self):
+        audit_log.info('delete counter entity=%s attr_key=%s value=%s', self.entity.name, self.attr_key, self.value)
+        SESSION.delete(self)
+        SESSION.flush()
+
     @classmethod
     def get(cls, entity, keyname, default=0):
 
@@ -192,6 +197,10 @@ class Counter(object):
 
         return ctr
 
+    @classmethod
+    def query(cls):
+        return SESSION.query(cls)
+
 class ProtectedObj(object):
 
     ## this is a hack to make these objects immutable-ish
@@ -521,6 +530,10 @@ class Entity(ProtectedObj):
 
         return str(self.name)
 
+    @property
+    def counters(self):
+        return Counter.query().filter(Counter.entity==self).all()
+
     @property
     def attrs(self):
         return Attribute.query().filter(Attribute.entity==self).all()
@@ -546,6 +559,9 @@ class Entity(ProtectedObj):
             for i in self.attrs:
                 i.delete()
 
+            for i in self.counters:
+                i.delete()
+
             if SESSION.clusto_versioning_enabled:
                 self.deleted_at_version = working_version()
             else:
